PR2AReq: Finds the equilibrium attack-rates for an input vector of...

Description Usage Arguments

View source: R/eq_sim.R

Description

Finds the equilibrium attack-rates for an input vector of prevalences, conditional on the chosen model and parameters

Usage

1
PR2AReq(X, Tx, PAR, Bfn, showMessages = F)

Arguments

X

A vector of prevalence rates

Tx

A vector of case-management rates

PAR

A set of model parameters

Bfn

A function for building the matrix represention of the system of equations that update the state vector

showMessages

Toggle for whether the function prints messages


aucarter/pr2ar documentation built on Nov. 3, 2019, 1:59 p.m.